# Changelog

## v0.2.0
- Fix the _populate_with_tags function
- Add `Tag.Focused` and `Tag.Hovered` messages that fire, if a `Tag` is hovered or focused

## v0.1.2
- fix duplication in Tags docstring

## v0.1.1
- fix bug, that already present tags can be added when `allow_new_tags=True`

## v0.1.0
- initial release
